function out = pcmmfccmean(x,p,skipbegin,skipend,framelen)
%PCMMFCCMEAN Compute MFCC + mean and variance in texture windows
%   C=PCMMFCCMEAN(X,P,SKIPBEG,SKIPEND,N) returns mean and variance in
%   texture windows of the MFCC of the signal X with parameters P (see
%   PCMMFCC for a list of parameters). The functions skips the first
%   SKIPBEG and the last SKIPEND frames. Mean and variance are computed in
%   texture windows of size N frames.

% Compute MFCC
c = pcmmfcc(x,p);

% Number of texture windows
numframes = floor((size(c,2)-skipbegin-skipend)/framelen);

%Init output
numcoefs = size(c,1);
out = zeros(numcoefs*2,numframes);

%Compute Mean and Var
for n=1:numframes
    
    idx = (n-1)*framelen+skipbegin+1:(n-1)*framelen+skipbegin+framelen;
    
    out(1:numcoefs,n) = mean(c(:,idx),2);
    out(numcoefs+1:2*numcoefs,n) = var(c(:,idx),0,2);
    
end